@@ -28,7 +28,7 @@ import math
 import sys
 import struct
 from Crypto import Random
-from Crypto.Util.py3compat import _memoryview, iter_range
+from Crypto.Util.py3compat import iter_range
 
 # Backward compatibility
 _fastmath = None
@@ -50,6 +50,9 @@ def ceil_div(n, d):
 def size (N):
     """Returns the size of the number N in bits."""
 
+    if N < 0:
+        raise ValueError("Size in bits only avialable for non-negative numbers")
+
     bits = 0
     while N >> bits:
         bits += 1
@@ -152,9 +155,9 @@ def getPrime(N, randfunc=None):
 def _rabinMillerTest(n, rounds, randfunc=None):
     """_rabinMillerTest(n:long, rounds:int, randfunc:callable):int
     Tests if n is prime.
-    Returns 0 when n is definitly composite.
+    Returns 0 when n is definitely composite.
     Returns 1 when n is probably prime.
-    Returns 2 when n is definitly prime.
+    Returns 2 when n is definitely prime.
 
     If randfunc is omitted, then Random.new().read is used.
 
@@ -436,7 +439,7 @@ def bytes_to_long(s):
     if sys.version_info[0:3] < (2, 7, 4):
         if isinstance(s, bytearray):
             s = bytes(s)
-        elif isinstance(s, _memoryview):
+        elif isinstance(s, memoryview):
             s = s.tobytes()
 
     length = len(s)
